#----------------------------------------------------------------------------------------------------------------------------------------------#

##### PTSD Symptom Network Analysis in U.S. Military Veterans: Examining the impact of combat exposure 
##### R. Phillips et al., 2018

#----------------------------------------------------------------------------------------------------------------------------------------------#

### Load libraries
library(dplyr)
library(qgraph)
library(car)
library(igraph)
library(networktools)
library(devtools)
install_github("paytonjjones/NetworkComparisonTest")
library(NetworkComparisonTest)
install_github("sachaepskamp/bootnet")
library(bootnet)
library(ggplot2)

### Data preparation
data <- read.csv("data.csv")
### Names ,labels, and groups for graphs
Names <- scan("nodeNames.txt", what = "character", sep = "\n")
LongLabels <- scan("longLabels.txt",what='character',sep='\n')
ShortLabels <- c("B1","B2", "B3", "B4", "B5", "C1", "C2", "D1", "D5", "D6", "D7", "E1", "E2", "E3", "E4", "E5", "E6")
Groups <- c(rep("Intrusion",5),rep("Avoidance",2),rep("Cognition and Mood",4),rep("Arousal and Reactivity",6))

#----------------------------------------------------------------------------------------------------------------------------------------------#

### 1. Data Preparation
# Clinical and subthreshold groups
clin <- data %>%
  filter(P96==3) #n=912
sub <- data %>%
  filter(P96==2) #n=138
# Subset of clinical population
set.seed(10)
clin_2 <- sample_n(clin,138,replace=FALSE) 
subset <- rbind(clin_2,sub)
# High vs. Low Combat Exposure groups (cut-score of 25)
ptsd <- data %>%
  filter(P96==3) #867
high_25 <- ptsd %>%
  filter(X_ces_score>=25) #n=273
low_25 <- ptsd %>%
  filter(X_ces_score<=24) #n=639

### 2. Group Variance Testing
var(clin$X_dts_severity) #284.75
var(sub$X_dts_severity) #193.11
var(clin_2$X_dts_severity) #265.50
var(low_25$X_dts_severity) #265.50
var(high_25$X_dts_severity) #242.03
var.test(clin$X_dts_severity, sub$X_dts_severity) #F = 1.4745, num df = 911, denom df = 137, p-value = 0.004
var.test(clin_2$X_dts_severity, sub$X_dts_severity) #F = 1.3748, num df = 137, denom df = 137, p-value = 0.063
var.test(low_25$X_dts_severity, high_25$X_dts_severity) #F = 1.2107, num df = 638, denom df = 272, p-value = 0.068

### 3. Estimate networks and plot structures
# Create data frames of 17 PTSD symptom variables that we need for analyis:
clin_3 <- as.data.frame(clin_2[,c("dts_1_2", "dts_2_2","dts_3_2", "dts_4_2", "dts_17_2", "dts_5_2", "dts_6_2","dts_7_2","dts_8_2", "dts_9_2","dts_10_2", "dts_13_2","dts_11_2", "dts_15_2","dts_16_2", "dts_14_2", "dts_12_2")])
clin_4 <- as.data.frame(clin[,c("dts_1_2", "dts_2_2","dts_3_2", "dts_4_2", "dts_17_2", "dts_5_2", "dts_6_2","dts_7_2","dts_8_2", "dts_9_2","dts_10_2", "dts_13_2","dts_11_2", "dts_15_2","dts_16_2", "dts_14_2", "dts_12_2")])
sub_2 <- as.data.frame(sub[,c("dts_1_2", "dts_2_2","dts_3_2", "dts_4_2", "dts_17_2", "dts_5_2", "dts_6_2","dts_7_2","dts_8_2", "dts_9_2","dts_10_2", "dts_13_2","dts_11_2", "dts_15_2","dts_16_2", "dts_14_2", "dts_12_2")])
low_25 <- as.data.frame(low_25[,c("dts_1_2", "dts_2_2","dts_3_2", "dts_4_2", "dts_17_2", "dts_5_2", "dts_6_2","dts_7_2","dts_8_2", "dts_9_2","dts_10_2", "dts_13_2","dts_11_2", "dts_15_2","dts_16_2", "dts_14_2", "dts_12_2")])
high_25 <- as.data.frame(high_25[,c("dts_1_2", "dts_2_2","dts_3_2", "dts_4_2", "dts_17_2", "dts_5_2", "dts_6_2","dts_7_2","dts_8_2", "dts_9_2","dts_10_2", "dts_13_2","dts_11_2", "dts_15_2","dts_16_2", "dts_14_2", "dts_12_2")])
# Estimate networks
network.c <- estimateNetwork(clin_3, default ='EBICglasso', corMethod = "cor_auto")
network.c2 <- estimateNetwork(clin_4, default='EBICglasso', corMethod = "cor_auto")
network.s <- estimateNetwork(sub_2, default ='EBICglasso', corMethod = "cor_auto")
network.l <- estimateNetwork(low_25, default ='EBICglasso', corMethod = "cor_auto")
network.h <- estimateNetwork(high_25, default ='EBICglasso', corMethod = "cor_auto")
# Print correlation matrices
write.csv(network.s$graph, file = "Clin_network.csv")
write.csv(network.s$graph, file = "Sub_network.csv")
write.csv(network.l$graph, file = "Low_network.csv")
write.csv(network.h$graph, file = "High_network.csv")
# Graph networks
graph.s <- plot(network.s, layout = "spring", cut=0, details=TRUE,labels=ShortLabels,minimum=0.05,nodeNames=Names,groups=Groups, palette="ggplot2",legend=FALSE) 
graph.c <- plot(network.c, layout = "spring", cut=0, details=TRUE,labels=ShortLabels,minimum=0.05,nodeNames=Names,groups=Groups, palette="ggplot2",legend.cex=0.35)
graph.l <- plot(network.l, layout = "spring", cut=0, details=TRUE,labels=ShortLabels,minimum=0.05, nodeNames=Names,groups=Groups, palette="ggplot2",legend.cex=0.35) 
graph.h <- plot(network.h, layout = "spring", cut=0, details=TRUE,labels=ShortLabels,minimum=0.05, nodeNames=Names,groups=Groups, palette="ggplot2",legend.cex=0.35) 
# Print all networks with the same layout
tiff("Networks_all.tiff", width=28, height=7.25,units='in',res = 600)
L <- averageLayout(graph.s,graph.c,graph.l,graph.h)
layout(t(1:4))
graph.s <- plot(network.s, layout=L,vsize=10,maximum=0.48,labels=ShortLabels,nodeNames=Names,groups=Groups, palette="ggplot2",legend=FALSE)
graph.c <- plot(network.c, layout=L,vsize=10,maximum=0.48,labels=ShortLabels,nodeNames=Names,groups=Groups, palette="ggplot2",legend=FALSE) 
graph.l <- plot(network.l, layout=L,vsize=10,maximum=0.55,labels=ShortLabels,nodeNames=Names,groups=Groups, palette="ggplot2",legend=FALSE)
graph.h <- plot(network.h, layout=L,vsize=10,maximum=0.55,labels=ShortLabels,nodeNames=Names,groups=Groups, palette="ggplot2",legend=FALSE) 
dev.off()
# Print centrality graphs
tiff(file="Figure1b.tiff",height=8,width=5.5,units='in',res=500)
plot<- centralityPlot(list(Clinical=graph.c, Subthreshold=graph.s),labels=LongLabels, include = "ExpectedInfluence")
dev.off()
tiff(file="Figure2b.tiff",height=8,width=5.5,units='in',res=500)
plot<- centralityPlot(list(High_CES_25=graph.h, Low_CES_25=graph.l),labels=LongLabels, include = "ExpectedInfluence")
dev.off()

### 4. Descriptive Statistics and Node/Edge Testing
# Mean and SD for individual nodes
colMeans(sub_2)
colMeans(clin_3)
colMeans(low_25)
colMeans(high_25)
as.vector(sapply(sub_2, sd))
as.vector(sapply(clin_3, sd))
as.vector(sapply(low_25, sd))
as.vector(sapply(high_25, sd))
# Mean edge weights for each network
mean(graph.s$Edgelist$weight) 
mean(graph.c$Edgelist$weight) 
mean(graph.l$Edgelist$weight) 
mean(graph.h$Edgelist$weight) 
## Correlation between node centrality and variance
# Clinical vs. Subthreshold
centrality_sub <- centrality(graph.s)
centrality_sub$OutDegree
cent_sub <- cbind(1.2438894,0.8192898,1.0225339,0.5815677,0.9053293,0.9514874,1.0119045,0.6557651,0.8579875,1.0181246,1.0614384,0.7517701,0.7146101,1.2311006,0.7544358,1.0445177,1.0093026)
var_sub <- cbind(var(sub_2$dts_1_2),var(sub_2$dts_2_2),var(sub_2$dts_3_2),var(sub_2$dts_4_2),var(sub_2$dts_17_2),var(sub_2$dts_5_2),var(sub_2$dts_6_2),
                 var(sub_2$dts_7_2),var(sub_2$dts_8_2),var(sub_2$dts_9_2),var(sub_2$dts_10_2),var(sub_2$dts_13_2),var(sub_2$dts_11_2),var(sub_2$dts_15_2),
                 var(sub_2$dts_16_2),var(sub_2$dts_14_2),var(sub_2$dts_12_2))
cor.test(cent_sub, var_sub, method = 'pearson') #t = 1.3526, df = 15, p-value = 0.1962, cor = 0.3297004
centrality_clin <- centrality(graph.c)
centrality_clin$OutDegree
cent_clin <- cbind(1.1919482,1.0169805,0.8867752,0.8161349,1.1375884,0.9932980,0.9853673,0.4907717,1.0427942,1.0459513,0.9232279,0.8629171,0.7223784,1.2444784,0.8030069,0.9147574,0.7153665)
var_clin <- cbind(var(clin_3$dts_1_2),var(clin_3$dts_2_2),var(clin_3$dts_3_2),var(clin_3$dts_4_2),var(clin_3$dts_17_2),var(clin_3$dts_5_2),var(clin_3$dts_6_2),
                  var(clin_3$dts_7_2),var(clin_3$dts_8_2),var(clin_3$dts_9_2),var(clin_3$dts_10_2),var(clin_3$dts_13_2),var(clin_3$dts_11_2),var(clin_3$dts_15_2),
                  var(clin_3$dts_16_2),var(clin_3$dts_14_2),var(clin_3$dts_12_2))
cor.test(cent_clin, var_clin, method = 'pearson') #t = -1.6395, df = 15, p-value = 0.1219, cor = -0.3898206
# Low vs. High Combat Exposure
centrality_low <- centrality(graph.l)
centrality_low$OutDegree
cent_low <- cbind(0.9083587,0.9581891,0.9842631,0.8214678,1.0748964,0.9651322,1.1786930,0.4503526,1.0902348,1.1219767,0.9020324,0.8219555,0.7888106,1.1928143,0.9153782,0.9038073,0.8171393)
var_low <- cbind(var(low_25$dts_1_2),var(low_25$dts_2_2),var(low_25$dts_3_2),var(low_25$dts_4_2),var(low_25$dts_17_2),var(low_25$dts_5_2),var(low_25$dts_6_2),
                 var(low_25$dts_7_2),var(low_25$dts_8_2),var(low_25$dts_9_2),var(low_25$dts_10_2),var(low_25$dts_13_2),var(low_25$dts_11_2),var(low_25$dts_15_2),
                 var(low_25$dts_16_2),var(low_25$dts_14_2),var(low_25$dts_12_2))
cor.test(cent_low, var_low, method = 'pearson') #t = -0.33263, df = 15, p-value = 0.744, cor = -0.08556844
centrality_high <- centrality(graph.h)
centrality_high$OutDegree
cent_high <- cbind(1.1799092,0.8436454,0.7261818,0.9694064,0.9975412,0.9051187,1.1178267,0.4011310,1.1658466,1.0252524,0.9777253,0.6516510,0.6960434,1.1620044,0.9440691,0.9678952,0.6599196)
var_high <- cbind(var(high_25$dts_1_2),var(high_25$dts_2_2),var(high_25$dts_3_2),var(high_25$dts_4_2),var(high_25$dts_17_2),var(high_25$dts_5_2),var(high_25$dts_6_2),
                  var(high_25$dts_7_2),var(high_25$dts_8_2),var(high_25$dts_9_2),var(high_25$dts_10_2),var(high_25$dts_13_2),var(high_25$dts_11_2),var(high_25$dts_15_2),
                  var(high_25$dts_16_2),var(high_25$dts_14_2),var(high_25$dts_12_2))
cor.test(cent_high, var_high, method = 'pearson') #t = -2.0905, df = 15, p-value = 0.05401, cor = -0.4749892


### 5. Network Comparison Test
clin <- as.data.frame(clin[,c("dts_1_2", "dts_2_2","dts_3_2", "dts_4_2", "dts_17_2", "dts_5_2", "dts_6_2","dts_7_2","dts_8_2", "dts_9_2",
                                    "dts_10_2", "dts_13_2","dts_11_2", "dts_15_2","dts_16_2", "dts_14_2", "dts_12_2")])
NCT_unequal <- NCT(sub_2,clin, it=2000, paired = FALSE, weighted = TRUE, test_edges = TRUE, test_centrality_node = TRUE, centrality_global = "ExpectedInfluence")
NCT_unequal$glstrinv.real #-0.670
NCT_unequal$glstrinv.pval #0
NCT_1<-NCT(sub_2, clin_3, it=2000, paired = FALSE, weighted = TRUE, test_edges = TRUE, test_centrality_node = TRUE, centrality_global = "ExpectedInfluence")
save(NCT_1,file='NCT_1.Rdata')
NCT_2<-NCT(low_25,high_25,it=2000,paired=FALSE, weighted=TRUE, test_edges = TRUE, test_centrality_node = TRUE, centrality_global = "ExpectedInfluence")
save(NCT_2,file='NCT_2.Rdata')
# NCT1 Results
NCT_1$glstrinv.sep #7.08 vs. 7.62
NCT_1$glstrinv.real # -0.535
NCT_1$glstrinv.pval #global expected influence: 0.002 
NCT_1$nwinv.real 
NCT_1$nwinv.pval 
NCT_1$einv.pvals[NCT_1$einv.pvals[,3]<0.05,] 
NCT_1$diffcen.pval 
# NCT2 Results
NCT_2$glstrinv.sep #7.79 vs. 7.57
NCT_2$glstrinv.real #0.220
NCT_2$glstrinv.pval #global expected influence: 0.013
NCT_2$nwinv.real 
NCT_2$nwinv.pval 
NCT_2$einv.pvals[NCT_2$einv.pvals[,3]<0.05,] 
NCT_2$diffcen.pval 
# NCT with unregularized networks
Test0<-NCT(sub_2, clin_3, estimation_method ="concentration", it=2000, centrality_global = c("ExpectedInfluence"))
Test0.1<-NCT(sub_2, clin, estimation_method ="concentration", it=2000, centrality_global = c("ExpectedInfluence"))
Test0.2<-NCT(low_25,high_25, estimation_method ="concentration", it=2000, centrality_global = c("ExpectedInfluence"))
Test0$glstrinv.pval 
Test0.1$glstrinv.pval 
Test0.2$glstrinv.pval 
# Pearson correlations
myfunc <- function(x){qgraph::EBICglasso(cor(x),500,gamma=0)}
Test1 <- NCT(sub_2, clin_3,it=2000,estimation_method = "custom", custom_estimation_method = myfunc)
Test1.2 <- NCT(low_25,high_25,it=2000,estimation_method = "custom", custom_estimation_method = myfunc)
Test1$glstrinv.pval 
Test1.2$glstrinv.pval 
# Compare node centralities - strength
Test2 <- NCT(sub_2, clin_3,test_centrality_node = TRUE,it=2000, centrality_node = "Strength")
Test2.2 <- NCT(low_25,high_25,test_centrality_node = TRUE,it=2000, centrality_node = "Strength")
Test2$glstrinv.pval 
Test2.2$glstrinv.pval 
Test2$diffcen.pval 
Test2.2$diffcen.pval 
# Compare node centralities - expected influence
Test3<-NCT(sub_2, clin_3,test_centrality_node =TRUE, it=2000, centrality_node="ExpectedInfluence")
Test3.2<-NCT(low_25,high_25,test_centrality_node =TRUE, it=2000, centrality_node="ExpectedInfluence")
Test3$glstrinv.pval 
Test3.2$glstrinv.pval 
Test3$diffcen.pval 
Test3.2$diffcen.pval 
# Use global expected influence instead of global strength
Test4 <- NCT(sub_2, clin_3, it=2000, centrality_global = c("ExpectedInfluence"))
Test4.2 <- NCT(high_25, low_25, it=2000, centrality_global = c("ExpectedInfluence"))
Test4$glstrinv.real
Test4$glstrinv.pval 
Test4.2$glstrinv.pval 

### 5. Network Stability Analysis
# Edge weight accuracy
boots1a <- bootnet(network.s, nBoots = 2000, nCores = 8, labels=ShortLabels)
boots1b <- bootnet(network.c, nBoots = 2000, nCores = 8, labels=ShortLabels)
boots1c <- bootnet(network.l, nBoots = 2000, nCores = 8, labels=ShortLabels)
boots1d <- bootnet(network.h, nBoots = 2000, nCores = 8, labels=ShortLabels)
pdf("FigureS1a.pdf", width=7, height=10) 
plot(boots1a, order="sample", labels=FALSE)
dev.off()
pdf("FigureS1b.pdf", width=7, height=10) 
plot(boots1b, order="sample", labels=FALSE)
dev.off()
pdf("FigureS1c.pdf", width=7, height=10) 
plot(boots1c, order="sample", labels=FALSE)
dev.off()
pdf("FigureS1d.pdf", width=7, height=10) 
plot(boots1d, order="sample", labels=FALSE)
dev.off()
tiff(file="FigureS1e.tiff",height=7, width=7, units='in',res = 500)
plot(boots1a, "edge", plot = "difference", onlyNonZero = TRUE, order = "sample")
dev.off()
tiff(file="FigureS1f.tiff",height=7, width=7, units='in',res = 500)
plot(boots1b, "edge", plot = "difference", onlyNonZero = TRUE, order = "sample")
dev.off()
tiff(file="FigureS1g.tiff",height=7, width=7, units='in',res = 500)
plot(boots1c, "edge", plot = "difference", onlyNonZero = TRUE, order = "sample")
dev.off()
tiff(file="FigureS1h.tiff",height=7, width=7, units='in',res = 500)
plot(boots1d, "edge", plot = "difference", onlyNonZero = TRUE, order = "sample")
dev.off()

# Centrality stability - Expected Influence
boots2a <- bootnet(network.s, nBoots=2000, nCores = 8, type = "case") #CS < 0.5
boots2b.1 <- bootnet(network.c, nBoots=2000, nCores = 8, type = "case") #CS < 0.5
boots2b <- bootnet(network.c2, nBoots=2000, nCores = 8, type = "case", statistics = c("expectedInfluence","strength","betweenness","closeness"))
boots2c <- bootnet(network.l, nBoots = 2000, nCores = 8, type = "case", statistics = c("expectedInfluence","strength","betweenness","closeness"))
boots2d <- bootnet(network.h, nBoots = 2000, nCores = 8, type = "case", statistics = c("expectedInfluence","strength","betweenness","closeness"))
save(boots2a,file='boot2a.Rdata')
save(boots2b.1,file='boot2b.1.Rdata')
save(boots2b,file='boot2b.Rdata')
save(boots2c,file='boot2c.Rdata')
save(boots2d,file='boot2d.Rdata')
corStability(boots2a) #strength = 0.203
corStability(boots2b.1) #strength = 0.283
corStability(boots2b, statistics = "expectedInfluence") #EI=0.75 - full-criteria with n=912
corStability(boots2c, statistics = "expectedInfluence") #EI=0.75 - low combat
corStability(boots2d, statistics = "expectedInfluence") #EI=0.67 - high combat
# Print Supplemental Figures
pdf("FigureS2a.pdf", width=10, height=7) 
plot(list(boots1a,boots2a), statistics = c("expectedInfluence","strength","betweenness","closeness"))
dev.off()
pdf("FigureS2b.pdf", width=10, height=7) 
plot(boots2b, statistics = c("expectedInfluence","strength","betweenness","closeness"))
dev.off()
pdf("FigureS2c.pdf", width=10, height=7) 
plot(boots2c, statistics = c("expectedInfluence","strength","betweenness","closeness"))
dev.off()
pdf("FigureS2d.pdf", width=10, height=7) 
plot(boots2d, statistics = c("expectedInfluence","strength","betweenness","closeness"))
dev.off()


#----------------------------------------------------------------------------------------------------------------------------------------------#

### 6. Node predictability
# Clinical
library(mgm)
clinNet <- estimateNetwork(clin_3, default="EBICglasso", corMethod = "cor", threshold=TRUE, corArgs =list(use = "pairwise.complete.obs"))
type=rep('g', 17) #g=gaussian, 17 = number of nodes in the network
fit1<-mgm(clin_3,type=type,level=rep(1,7))
pred1<- predict(fit1, clin_3)
mean(pred1$error$R2) #0.54 #on average, 54% of the variance of the node in the network can be explained by its neighbors.
pred1$error$R2 #minimum=0.172 (D1)  ; maximum= 0.706 (E3)
graph1 <- plot(clinNet, pie = pred1$error$R2, labels=ShortLabels,layout="spring", legend.cex=.45,vsize=7, border.width=2, nodeNames=Names,groups=Groups, palette="ggplot2",legend.cex=0.35)
# Subthreshold
subNet <- estimateNetwork(sub_2, default="EBICglasso", corMethod = "cor", threshold=TRUE, corArgs =list(use = "pairwise.complete.obs"))
fit2<-mgm(sub_2,type=type,level=rep(1,7))
pred2<- predict(fit2, sub_2)
mean(pred2$error$R2) #0.46
pred2$error$R2 #min=0.175 (D1)l max=0.607 tied B1 and D6 detachment
graph2 <- plot(subNet, pie = pred2$error$R2, labels=ShortLabels,layout="spring", legend.cex=.45,vsize=7, border.width=2, nodeNames=Names,groups=Groups, palette="ggplot2",legend.cex=0.35)

# Low CES
fit3<-mgm(low_25,type=type,level=rep(1,7))
pred3<- predict(fit3, low_25)
mean(pred3$error$R2) #0.548
pred3$error$R2 
#minimum=0.230 (trauma-related amnesia)  ; maximum=0.659 (hypervigilance), nextmax=0.640 (detachment)
lowNet <- estimateNetwork(low_25, default="EBICglasso", corMethod = "cor", threshold=TRUE, corArgs =list(use = "pairwise.complete.obs"))
graph3 <- plot(lowNet, pie = pred3$error$R2, labels=ShortLabels,layout="spring", legend.cex=.45,vsize=7, border.width=2, nodeNames=Names,groups=Groups, palette="ggplot2",legend.cex=0.35)
# High CES
fit4<-mgm(high_25,type=type,level=rep(1,7))
pred4<- predict(fit4, high_25)
mean(pred4$error$R2) #0.527
pred4$error$R2 
#minimum=0.187 (trauma-related amnesia)  ; maximum=0.678 (E3), 0.625 (E4)
highNet <- estimateNetwork(high_25, default="EBICglasso", corMethod = "cor", threshold=TRUE, corArgs =list(use = "pairwise.complete.obs"))
graph4 <- plot(highNet, pie = pred4$error$R2, labels=ShortLabels,layout="spring", legend.cex=.45,vsize=7, border.width=2, nodeNames=Names,groups=Groups, palette="ggplot2",legend.cex=0.35)

# Print side-by-side comparison
tiff("Predictability_all.tiff", width=28, height=7.25,units='in',res = 600)
T <- averageLayout(graph2,graph1,graph3,graph4)
layout(t(1:4))
plot(subNet,layout=T,cut=0,vsize=10,maximum=0.55,pie = pred1$error$R2, labels=ShortLabels,vsize=7, border.width=2, nodeNames=Names,groups=Groups, palette="ggplot2", legend=FALSE)
plot(clinNet,layout=T,cut=0,vsize=10,maximum=0.55,pie = pred2$error$R2, labels=ShortLabels,vsize=7, border.width=2, nodeNames=Names,groups=Groups, palette="ggplot2", legend=FALSE)
plot(lowNet,layout=T,cut=0,vsize=10,maximum-0.55,pie = pred3$error$R2, labels=ShortLabels,vsize=7, border.width=2, nodeNames=Names,groups=Groups, palette="ggplot2", legend=FALSE)
plot(highNet,layout=T,cut=0,vsize=10,maximum=0.55,pie = pred4$error$R2, labels=ShortLabels,vsize=7, border.width=2, nodeNames=Names,groups=Groups, palette="ggplot2", legend=FALSE)
dev.off()

#----------------------------------------------------------------------------------------------------------------------------------------------#

# Age NCT at median split
# young <- data %>%
#   filter(registry_age_at_visit<36) #n=569
# old <- data %>%
#   filter(registry_age_at_visit>=36) #n=481
# young <- as.data.frame(young[,c("dts_1_2", "dts_2_2","dts_3_2", "dts_4_2", "dts_17_2", "dts_5_2", "dts_6_2",
#                                "dts_7_2","dts_8_2", "dts_9_2", "dts_10_2", "dts_13_2","dts_11_2", "dts_15_2", 
#                                "dts_16_2", "dts_14_2", "dts_12_2")])
# old <- as.data.frame(old[,c("dts_1_2", "dts_2_2","dts_3_2", "dts_4_2", "dts_17_2", "dts_5_2", "dts_6_2",
#                            "dts_7_2","dts_8_2", "dts_9_2", "dts_10_2", "dts_13_2","dts_11_2", "dts_15_2", 
#                           "dts_16_2", "dts_14_2", "dts_12_2")])
# NCT_Age<-NCT(young,old,it=1000,paired=FALSE,weighted=TRUE,test_edges=TRUE,progressbar=TRUE)

# Controlling for Combat Exposure in Full-Criteria
# clin_5 <- clin_2 %>%
#   filter(X_ces_score<=28)
# clin_6 <- as.data.frame(clin_5[,c("dts_1_2", "dts_2_2", "dts_3_2", "dts_4_2", "dts_17_2", "dts_5_2","dts_6_2","dts_7_2", "dts_8_2", 
#                                   "dts_9_2", "dts_10_2", "dts_13_2","dts_11_2", "dts_15_2","dts_16_2", "dts_14_2", "dts_12_2")])
# NCT_3 <- NCT(clin_6, sub, it=2000,paired=FALSE, weighted=TRUE, test_edges = TRUE, test_centrality_node = TRUE, centrality_global = "ExpectedInfluence")
# 
# network.c3 <- estimateNetwork(clin_6, default='EBICglasso', corMethod = "cor_auto")
# write.csv(network.c3$graph, file = "Clin_network_ces.csv")


### Supplemental Combat Exposure Comparisons
#Creates groups that differ significantly in variance

### 3. High vs. Low Combat Exposure Network Comparison (cut-score of 17)
#low_17 <- ptsd %>%
#  filter(X_ces_score<=16) #n=408
#high_17 <- ptsd %>%
#  filter(X_ces_score>=17) #n=504

## a. Group Variance Testing
# a1. Cut-score of 17
#var(low_17$X_dts_severity) #312.
#var(high_17$X_dts_severity) #249.46
#var.test(low_17$X_dts_severity, high_17$X_dts_severity) #F = 1.1964, num df = 498, denom df = 550, p-value = 0.04014

### 4. High vs. Low Combat Exposure Network Comparison (cut-score of 9)
#low_9 <- ptsd %>%
#  filter(X_ces_score<=8) #n=254
#high_9 <- ptsd %>%
#  filter(X_ces_score>=9) #n=796

## a. Group Variance Testing
# a1. Cut-score of 9
#var(low_9$X_dts_severity) #373.45
#var(high_9$X_dts_severity) #282.38
#var.test(low_9$X_dts_severity, high_9$X_dts_severity) #F = 1.3225, num df = 253, denom df = 795, p-value = 0.004825
# a2. Histogram plots (Supplemental Figure 4)
#hist(low_9$X_dts_severity, xlab = "Low Combat Exposed DTS severity scores", main = "Low Combat Exposure")
#hist(high_9$X_dts_severity, xlab = "High Combat Exposed DTS severity scores", main = "High Combat Exposure")


